@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.41 2004/01/05 12:15:36 sts Exp $
+# $Id: Split.pm,v 0.42 2004/01/05 12:15:36 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use 5.6.1;
 use strict;
@@ -90,59 +90,94 @@ splitting tries to keep up the contentual recognition of data.
 
 =head2 new
 
-Creates an object. C<%options> contains the key / value pairs
-which will influence the splitting process.
+Creates an object. The key / value pairs may be supplied as
+hash reference or directly dumped to the constructor.
 
  $dir = Dir::Split->new (\%options);
 
+ or
+
+ $dir = Dir::Split->new (
+      mode    =>    'num',
+
+      source  =>    '/source',
+      target  =>    '/target',
+
+      options => {  verbose      =>         1,
+                    override     =>         0,
+      },
+      sub_dir => {  identifier   =>     'sub',
+                    file_limit   =>         2,
+                    file_sort    =>       '+',
+      },
+      suffix  => {  separator    =>       '-',
+                    continue     =>         1,
+                    length       =>         5,
+      },
+ );
+
 =cut
 
 sub new {
-    my ($pkg, $Opt_ref) = @_;
-    croak q~Usage: Dir::Split->new (\%options)~
-      unless ref $Opt_ref eq 'HASH';
+    my $pkg = shift;
 
     my $class = ref ($pkg) || $pkg;
 
-    return bless _tie_var($Opt_ref), $class;
+    if (ref $_[0]) { return bless _tie_var($_[0]), $class }
+    else { return bless _tie_var(@_), $class }
 }
 
 #
-# _tie_var (\%hash)
+# _tie_var (\%hash | %hash)
 #
-# ``Ties" class data.
+# ``Ties" class data as in %assign.
 #
 
 sub _tie_var {
-    my $opt_ref = $_[0];
+    my (%assign, %assigned); 
 
-    my %assign = (  mode    =>    'mode',
+    %assign = (  mode    =>    'mode',
 
-                    source  =>    'source',
-                    target  =>    'target',
-
-                    options => {  verbose     =>      'verbose',
-                                  override    =>     'override',
-                    },
-                    sub_dir => {  identifier  =>        'ident',
-                                  file_limit  =>      'f_limit',
-                                  file_sort   =>       'f_sort',
-                    },
-                    suffix  => {  separator   =>          'sep',
-                                  continue    =>   'num_contin',
-                                  length      =>       'length',
-                                  case        =>         'case',
-                    },
+                 source  =>    'source',
+                 target  =>    'target',
+    
+                 options => {  verbose     =>      'verbose',
+                               override    =>     'override',
+                 },
+                 sub_dir => {  identifier  =>        'ident',
+                               file_limit  =>      'f_limit',
+                               file_sort   =>       'f_sort',
+                 },
+                 suffix  => {  separator   =>          'sep',
+                               continue    =>   'num_contin',
+                               length      =>       'length',
+                               case        =>         'case',
+                 },
     );
 
-    my %assigned;
-    foreach my $key (keys %$opt_ref) {
-        if (ref $$opt_ref{$key} eq 'HASH') {
-            foreach ( keys %{$$opt_ref{$key}} ) {
-                $assigned{$assign{$key}{$_}} = $$opt_ref{$key}{$_};
+    # hash ref
+    if (ref $_[0]) {
+        my $opt = $_[0];
+        foreach my $key (keys %{$opt}) {
+            if (ref ${$opt}{$key} eq 'HASH') {
+                foreach (keys %{${$opt}{$key}}) {
+                    $assigned{$assign{$key}{$_}} = ${$opt}{$key}{$_};
+                }
             }
+            else { $assigned{$assign{$key}} = ${$opt}{$key} }
+        }
+    }
+    # hash
+    else {
+        my %opt = @_;
+        foreach my $key (keys %opt) {
+            if (ref $opt{$key} eq 'HASH') {
+                foreach (keys %{$opt{$key}}) {
+                    $assigned{$assign{$key}{$_}} = $opt{$key}{$_};
+                }
+            }
+            else { $assigned{$assign{$key}} = $opt{$key} }
         }
-        else { $assigned{$assign{$key}} = $$opt_ref{$key} }
     }
 
     return \%assigned;
@@ -154,7 +189,7 @@ sub _tie_var {
 
 Split files to subdirectories.
 
- $return = $dir->split;
+ $return = $dir->split();
 
 It is of tremendous importance to notice that checking the return code is a B<must>.
 Leaving the return code untouched will not allow appropriate gathering of harmless
@@ -239,7 +274,9 @@ sub _sanity_input {
     );
 
     my $err_input;
-    {   # generic opts
+    {   no warnings;
+
+        # generic opts
         unless ($o->{'mode'} eq 'num' || $o->{'mode'} eq 'char') {
             $err_input = $err_msg{'mode'}; last;
         }
